@@ -18,10 +18,31 @@
 package plugin
 
 import (
+	"fmt"
+
 	"git.zabbix.com/ap/plugin-support/conf"
 	"git.zabbix.com/ap/plugin-support/plugin"
 )
 
+const (
+	empty   = ""
+	req     = "required"
+	reqCa   = "verify_ca"
+	reqFull = "verify_full"
+)
+
+var validTLSOptions = []string{empty, req, reqCa, reqFull}
+
+type Session struct {
+	URI         string `conf:"name=Uri,optional"`
+	Password    string `conf:"optional"`
+	User        string `conf:"optional"`
+	TLSConnect  string `conf:"name=TLSConnect,optional"`
+	TLSCAFile   string `conf:"name=TLSCAFile,optional"`
+	TLSCertFile string `conf:"name=TLSCertFile,optional"`
+	TLSKeyFile  string `conf:"name=TLSKeyFile,optional"`
+}
+
 type PluginOptions struct {
 	plugin.SystemOptions `conf:"optional,name=System"`
 	// Timeout is the amount of time to wait for a server to respond when
@@ -32,7 +53,7 @@ type PluginOptions struct {
 	KeepAlive int `conf:"optional,range=60:900,default=60"`
 
 	// Sessions stores pre-defined named sets of connections settings.
-	Sessions map[string]conf.Session `conf:"optional"`
+	Sessions map[string]Session `conf:"optional"`
 }
 
 // Configure implements the Configurator interface.
@@ -52,5 +73,26 @@ func (p *Plugin) Configure(global *plugin.GlobalOptions, options interface{}) {
 func (p *Plugin) Validate(options interface{}) error {
 	var opts PluginOptions
 
-	return conf.Unmarshal(options, &opts)
+	err := conf.Unmarshal(options, &opts)
+	if err != nil {
+		return err
+	}
+
+	for _, s := range opts.Sessions {
+		if !contains(validTLSOptions, s.TLSConnect) {
+			return fmt.Errorf("incorrect tls connection type %s", s.TLSConnect)
+		}
+	}
+
+	return nil
+}
+
+func contains(s []string, e string) bool {
+	for _, v := range s {
+		if v == e {
+			return true
+		}
+	}
+
+	return false
 }
